﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Xml.Linq;
using ThinkGeo.MapSuite.Core;

public class KMLFeatureSource : FeatureSource
{
    private XElement xElement;

    public KMLFeatureSource()
        : this(string.Empty)
    { }

    public KMLFeatureSource(string kmlFilePath)
        : base()
    {
        this.KmlFilePath = kmlFilePath;
    }

    public string KmlFilePath
    { get; set; }


    protected override void OpenCore()
    {
        xElement = XElement.Load(KmlFilePath);
        base.OpenCore();
    }

    protected override Collection<Feature> GetAllFeaturesCore(IEnumerable<string> returningColumnNames)
    {
        Collection<Feature> results = new Collection<Feature>();
        foreach (var node in xElement.Nodes())
        {
            results.Add(GetFeatureFromXNode(node, returningColumnNames));
        }
        return results;
    }

    private Feature GetFeatureFromXNode(XNode xNode, IEnumerable<string> returningColumnNames)
    {
        string point = ((XElement)xNode).Element("Point").Value;

        string[] coordinates = point.Split(',');
        PointShape pointShape = new PointShape(Double.Parse(coordinates[0]), Double.Parse(coordinates[1]));
        
        return new Feature(pointShape);
    }
}